// This is a cut-down version of the same file found in the node-oracledb
// driver located at https://github.com/oracle/node-oracledb; this file is
// solely for the purpose of testing Node issue 28988

#include "njsModule.h"

//-----------------------------------------------------------------------------
// njsModule_externalInit()
//   Called by the JavaScript library to initialize the library. This extends
// each of the classes defined in the JavaScript library by adding constants
// and methods.
//-----------------------------------------------------------------------------
static napi_value njsModule_externalInit(napi_env env, napi_callback_info info)
{
    napi_value instance, thisArg;
    njsOracleDb *oracleDb;
    size_t actualArgs = 1;

    // verify that the OracleDb instance has been passed through
    if (napi_get_cb_info(env, info, &actualArgs, &instance, &thisArg,
            NULL) != napi_ok) {
        njsUtils_genericThrowError(env);
        return NULL;
    }
    if (actualArgs != 1) {
        njsUtils_throwError(env, errInvalidNumberOfParameters);
        return NULL;
    }

    // perform initializations for C structure
    if (!njsOracleDb_new(env, instance, &oracleDb))
        return NULL;

    // prepare classes for use
    if (!njsOracleDb_prepareClass(oracleDb, env, instance,
            &njsClassDefOracleDb, NULL))
        return NULL;
    if (!njsOracleDb_prepareClass(oracleDb, env, instance,
            &njsClassDefConnection, &oracleDb->jsConnectionConstructor))
        return NULL;

    return NULL;
}


//-----------------------------------------------------------------------------
// njsModule_init()
//   Initializer for the module. This defines all of the property and methods
// exported by the module.
//-----------------------------------------------------------------------------
static napi_value njsModule_init(napi_env env, napi_value exports)
{
    napi_value fn;

    // define function for initializing classes
    if (napi_create_function(env, "init", NAPI_AUTO_LENGTH,
            njsModule_externalInit, NULL, &fn) != napi_ok) {
        njsUtils_genericThrowError(env);
        return NULL;
    }
    if (napi_set_named_property(env, exports, "init", fn) != napi_ok) {
        njsUtils_genericThrowError(env);
        return NULL;
    }

    return exports;
}

NAPI_MODULE(NODE_GYP_MODULE_NAME, njsModule_init)
